==> opensearch-dashboards-2.6.0.tgz: opensearch-dashboards/src/plugins/opensearch_ui_shared/static/forms/helpers/de_serializers.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.multiSelectComponent = void 0;

/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
const multiSelectComponent = {
  // This deSerializer takes the previously selected options and map them
  // against the default select options values.
  selectedValueToOptions(selectOptions) {
    return defaultFormValue => {
      // If there are no default form value, it means that no previous value has been selected.
      if (!defaultFormValue) {
        return selectOptions;
      }

      return selectOptions.map(option => ({ ...option,
        checked: defaultFormValue.includes(option.label) ? 'on' : undefined
      }));
    };
  }

};
exports.multiSelectComponent = multiSelectComponent;

==> opensearch-dashboards-2.19.1.tgz: opensearch-dashboards/src/plugins/opensearch_ui_shared/static/forms/helpers/de_serializers.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.multiSelectComponent = void 0;
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

const multiSelectComponent = exports.multiSelectComponent = {
  // This deSerializer takes the previously selected options and map them
  // against the default select options values.
  selectedValueToOptions(selectOptions) {
    return defaultFormValue => {
      // If there are no default form value, it means that no previous value has been selected.
      if (!defaultFormValue) {
        return selectOptions;
      }
      return selectOptions.map(option => ({
        ...option,
        checked: defaultFormValue.includes(option.label) ? 'on' : undefined
      }));
    };
  }
};
